@@ -1,13 +1,14 @@
 import improviser.Ensembles.Bands as Bands
-import improviser.Progressions.Contemporary as Contemporary
+from improviser.Progressions import *
 
 class Block:
 
-	progressions = Contemporary.reincarnatie
+	progressions = Jazz.african_flower
 	
 	bpm = 200
 	resolution = 8
 	meter = (4,4)
+	duration = 2
 
 	swing = True
 	key = 'A'
@@ -18,6 +19,11 @@ class Block:
 	def get_bpm(self, iterations, tick):
 		return self.bpm
 
+	def get_duration(self):
+		p = self.progressions
+		song_length = p[-1][0] - p[0][0]
+		return self.duration * song_length - 1
+
 	def get_key(self, iteration):
 		return self.key
 
@@ -29,6 +35,7 @@ class Block:
 
 	def get_progression(self, iteration):
 		p = self.progressions
+		iteration -= 1
 		res = []
 		for i in range(len(p)):
 			if i < len(p) - 1:
@@ -43,7 +50,7 @@ class Block:
 			for prog in p:
 				p[p.index(prog)] = \
 					(prog[0] + song_length, prog[1])
-			return self.get_progression(iteration)
+			return self.get_progression(iteration + 1)
 		return res
 
 
