@@ -63,8 +63,7 @@ class Instrument:
 		if 'wild' in state:
 			wild = state['wild']
 
-		if state["tick"] % \
-			(state["resolution"] / state["meter"][1]) == 0:
+		if state["tick"] % (state["resolution"] / float(state["meter"][1])) == 0:
 			velocity = randrange(maxv - 10, maxv)
 		else:
 			velocity = randrange(minv, maxv)
