@@ -10,12 +10,12 @@ class BassInstrument(Instrument):
 		if 'wild' in state:
 			wild = state['wild']
 
-		if state["tick"] % (state["resolution"] / 4) == 0 and \
+		if state["tick"] % (state["resolution"] / 4.0) == 0 and \
 				random() < 1.0 * wild:
 			n = Note(choice(state["chord"]))
 			n.octave_down()
 			return [n]
-		elif state["tick"] % (state["resolution"] / 4) == \
+		elif state["tick"] % (state["resolution"] / 4.0) == \
 				state["resolution"] / 8 and \
 				random() < 0.2 * wild:
 			
