@@ -8,8 +8,10 @@ from random import random
 class SlowStridePianist(Instrument):
 
 	def __init__(self, params):
-		params["let_ring"] = True
-		params["channel"] = 1
+		if 'let_ring' not in params:
+			params["let_ring"] = True
+		if 'channel' not in params:
+			params["channel"] = 1
 		Instrument.__init__(self, params)
 
 	def generate_note(self, state):
